@@ -36,10 +36,7 @@ import traceback
 
 from threading import Thread
 
-try:
-    __version__ = __import__('pkg_resources').get_distribution('sqlitedict').version
-except:
-    __version__ = '?'
+__version__ = '1.7.0'
 
 major_version = sys.version_info[0]
 if major_version < 3:  # py <= 2.x
@@ -160,15 +157,17 @@ class SqliteDict(DictClass):
                 raise RuntimeError('Error! The directory does not exist, %s' % dirname)
 
         self.filename = filename
-        if '"' in tablename:
-            raise ValueError('Invalid tablename %r' % tablename)
-        self.tablename = tablename
+
+        # Use standard SQL escaping of double quote characters in identifiers, by doubling them.
+        # See https://github.com/RaRe-Technologies/sqlitedict/pull/113
+        self.tablename = tablename.replace('"', '""')
+
         self.autocommit = autocommit
         self.journal_mode = journal_mode
         self.encode = encode
         self.decode = decode
 
-        logger.info("opening Sqlite table %r in %s" % (tablename, filename))
+        logger.info("opening Sqlite table %r in %r" % (tablename, filename))
         MAKE_TABLE = 'CREATE TABLE IF NOT EXISTS "%s" (key TEXT PRIMARY KEY, value BLOB)' % self.tablename
         self.conn = self._new_conn()
         self.conn.execute(MAKE_TABLE)
@@ -251,6 +250,8 @@ class SqliteDict(DictClass):
 
         ADD_ITEM = 'REPLACE INTO "%s" (key, value) VALUES (?,?)' % self.tablename
         self.conn.execute(ADD_ITEM, (key, self.encode(value)))
+        if self.autocommit:
+            self.commit()
 
     def __delitem__(self, key):
         if self.flag == 'r':
@@ -260,6 +261,8 @@ class SqliteDict(DictClass):
             raise KeyError(key)
         DEL_ITEM = 'DELETE FROM "%s" WHERE key = ?' % self.tablename
         self.conn.execute(DEL_ITEM, (key,))
+        if self.autocommit:
+            self.commit()
 
     def update(self, items=(), **kwds):
         if self.flag == 'r':
@@ -275,6 +278,8 @@ class SqliteDict(DictClass):
         self.conn.executemany(UPDATE_ITEMS, items)
         if kwds:
             self.update(kwds)
+        if self.autocommit:
+            self.commit()
 
     def __iter__(self):
         return self.iterkeys()
